summaryrefslogtreecommitdiff
path: root/dicore3/command/src/main/java/io/dico/dicore/command/chat/help/IHelpTopic.java
diff options
context:
space:
mode:
Diffstat (limited to 'dicore3/command/src/main/java/io/dico/dicore/command/chat/help/IHelpTopic.java')
-rw-r--r--dicore3/command/src/main/java/io/dico/dicore/command/chat/help/IHelpTopic.java9
1 files changed, 5 insertions, 4 deletions
diff --git a/dicore3/command/src/main/java/io/dico/dicore/command/chat/help/IHelpTopic.java b/dicore3/command/src/main/java/io/dico/dicore/command/chat/help/IHelpTopic.java
index 618109e..0b3fba2 100644
--- a/dicore3/command/src/main/java/io/dico/dicore/command/chat/help/IHelpTopic.java
+++ b/dicore3/command/src/main/java/io/dico/dicore/command/chat/help/IHelpTopic.java
@@ -11,12 +11,13 @@ public interface IHelpTopic {
/**
* Get the components of this help topic
*
* @param target The address of the command to provide help about
* @param viewer The permissible that the page will be shown to (null -> choose a default set).
* @param context Context of the command execution
* @return a mutable list of components to include in the help pages
*/
- List<IHelpComponent> getComponents(ICommandAddress target, Permissible viewer, ExecutionContext context);
+ List<IHelpComponent> getComponents(ICommandAddress target, Permissible viewer, ExecutionContext context, boolean isForPage);
}
@@ -11,12 +11,13 @@ public interface IHelpTopic {
* Get the components of this help topic
*
- * @param target The address of the command to provide help about
- * @param viewer The permissible that the page will be shown to (null -> choose a default set).
- * @param context Context of the command execution
+ * @param target The address of the command to provide help about
+ * @param viewer The permissible that the page will be shown to (null -> choose a default set).
+ * @param context Context of the command execution
+ * @param isForPage A boolean indicating if the components are to be used in a page (for help)
* @return a mutable list of components to include in the help pages
*/